<?php

if (file_exists('../../../dbconnect.php')) {
    include('../../../dbconnect.php');
} elseif (file_exists('../../../init.php')) {
    define('WHMCSDBCONNECT', true);
    include('../../../init.php');
} else {
    die('Initialization file not found.');
}

include('../../../includes/functions.php');
include('../../../includes/gatewayfunctions.php');
include('../../../includes/invoicefunctions.php');

function getPay3ResponseStatus($code)
{
    $statusMessages = [
        2  => 'Parameters not filled correctly.',
        3  => 'Parameters contain errors.',
        4  => 'Gateway is empty.',
        5  => 'Amount is empty.',
        6  => 'Callback URL is empty.',
        7  => 'Amount is not valid.',
        8  => 'Callback URL is not valid.',
        9  => 'Gateway not found.',
        10 => 'Account not accepted.',
        11 => 'Gateway not accepted.',
        12 => 'Insufficient wallet balance.',
        100 => 'Transaction successful.',
        'NOK' => 'Payment canceled by user.',
    ];

    return $statusMessages[$code] ?? "Unexpected error. Code: $code";
}

$gatewayModule = 'pay3';
$gatewayParams = getGatewayVariables($gatewayModule);

if (!$gatewayParams['type']) {
    die('Pay3 payment gateway is not enabled.');
}

$invoiceId = checkCbInvoiceID($_GET['invoiceid'], $gatewayParams['name']);
$invoiceData = select_query('tblinvoices', 'total', ['id' => $invoiceId]);
list($amount) = mysql_fetch_array($invoiceData);

try {
    $verifyUrl = "https://pay3.ir/api/payment/verify/" . $_GET['authority'];

    $ch = curl_init($verifyUrl);
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

    $response = curl_exec($ch);

    if (curl_errno($ch)) {
        throw new Exception('cURL Error: ' . curl_error($ch));
    }

    curl_close($ch);

    $responseData = json_decode($response, true);

    // Verifying based on returned status
    if ($responseData['status'] == true && !empty($responseData['paid_at'])) {

        // Check for duplicate transaction using the hash
        checkCbTransID($responseData['hash']);

        // Add payment to WHMCS
        addInvoicePayment($invoiceId, $responseData['hash'], $amount, 0, $gatewayModule);

        $message = "Payment completed successfully. Invoice ID: $invoiceId. Transaction Hash: " . $responseData['hash'];
        logTransaction($gatewayParams['name'], array_merge($_GET, $responseData, ['message' => $message]), 'Successful');
    } else {

        $message = 'Transaction canceled by user.';
        logTransaction($gatewayParams['name'], array_merge($_GET, ['message' => $message]), 'Unsuccessful');

    }
} catch (Exception $e) {
    $errorMessage = "An error occurred during payment verification: " . $e->getMessage();
    logTransaction($gatewayParams['name'], ['error' => $errorMessage], 'Unsuccessful');
    die($errorMessage);
}

header('Location: ' . $CONFIG['SystemURL'] . '/viewinvoice.php?id=' . $invoiceId);
exit;
